==> gchempaint-0.5.2.tar.gz: gchempaint-0.5.2/lib/molecule.h <==
// -*- C++ -*-

/* 
 * GChemPaint library
 * molecule.h 
 *
 * Copyright (C) 2001-2004
 *
 * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GCHEMPAINT_MOLECULE_H
#define GCHEMPAINT_MOLECULE_H

#include "cycle.h"
#include "fragment.h"
#include <list>

class gcpMolecule: public Object
{
public:
	gcpMolecule(TypeId Type = MoleculeType);
	gcpMolecule(gcpAtom* pAtom);
	virtual ~gcpMolecule();
	void AddAtom(gcpAtom* pAtom);
	void AddFragment(gcpFragment* pFragment);
	void AddBond(gcpBond* pBond);
	void Remove(Object* pObject);
	void UpdateCycles(gcpBond* pBond);
	bool Merge(gcpMolecule* pMolecule, bool RemoveDuplicates = false);
	void UpdateCycles();
	virtual bool Load(xmlNodePtr);
	void Clear();
	virtual void SetSelected(GtkWidget* w, int state);
	virtual void Transform2D(Matrix2D& m, double x, double y);
	virtual Object* GetAtomAt(double x, double y, double z = 0.);
	virtual double GetYAlign ();
	virtual bool BuildContextualMenu (GtkUIManager *UIManager);
	void ExportToGhemical ();
	void SelectAlignmentItem ();

private:
	list<gcpCycle*> m_Cycles;
	list<gcpChain*> m_Chains;
	list<gcpAtom*> m_Atoms;
	list<gcpFragment*> m_Fragments;
	list<gcpBond*> m_Bonds;
	Object *m_Alignment;
};

#endif // GCHEMPAINT_MOLECULE_H

==> gchempaint-0.5.3.tar.gz: gchempaint-0.5.3/lib/molecule.h <==
// -*- C++ -*-

/* 
 * GChemPaint library
 * molecule.h 
 *
 * Copyright (C) 2001-2004
 *
 * Developed by Jean Bréfort <jean.brefort@normalesup.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GCHEMPAINT_MOLECULE_H
#define GCHEMPAINT_MOLECULE_H

#include "cycle.h"
#include "fragment.h"
#include <list>

class gcpMolecule: public Object
{
public:
	gcpMolecule(TypeId Type = MoleculeType);
	gcpMolecule(gcpAtom* pAtom);
	virtual ~gcpMolecule();
	void AddAtom(gcpAtom* pAtom);
	void AddFragment(gcpFragment* pFragment);
	void AddBond(gcpBond* pBond);
	void Remove(Object* pObject);
	void UpdateCycles(gcpBond* pBond);
	bool Merge(gcpMolecule* pMolecule, bool RemoveDuplicates = false);
	void UpdateCycles();
	virtual bool Load(xmlNodePtr);
	virtual xmlNodePtr Save(xmlDocPtr xml);
	void Clear();
	virtual void SetSelected(GtkWidget* w, int state);
	virtual void Transform2D(Matrix2D& m, double x, double y);
	virtual Object* GetAtomAt(double x, double y, double z = 0.);
	virtual double GetYAlign ();
	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
	void ExportToGhemical ();
	void SelectAlignmentItem (Object *child);

private:
	list<gcpCycle*> m_Cycles;
	list<gcpChain*> m_Chains;
	list<gcpAtom*> m_Atoms;
	list<gcpFragment*> m_Fragments;
	list<gcpBond*> m_Bonds;
	Object *m_Alignment;
};

#endif // GCHEMPAINT_MOLECULE_H
